==> estateplat-common-1.2.4-20210924.065539-894-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxClxx.java <==
package cn.gtmap.estateplat.model.exchange.share;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0
 * @description 外网申请材料信息表
 */
@Table(name = "GX_WW_SQXX_CLXX")
public class GxWwSqxxClxx implements Serializable {
    private static final long serialVersionUID = 7007384048258765364L;
    @Id
    private String clid;
    private String clmc;//材料名称
    private String sqxxid;//GX_WW_SQXX id
    private String cllx;//材料类型
    private Integer xh;//序号
    private String xmid;//项目ID
    private Integer fs;//份数

    public String getClid() {
        return clid;
    }

    public void setClid(String clid) {
        this.clid = clid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Integer getFs() {
        return fs;
    }

    public void setFs(Integer fs) {
        this.fs = fs;
    }
}

==> estateplat-common-1.2.4-20220624.070313-1054-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxClxx.java <==
package cn.gtmap.estateplat.model.exchange.share;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:xuchao@gtmap.cn">xuchao</a>
 * @version 1.0
 * @description 外网申请材料信息表
 */
@Table(name = "GX_WW_SQXX_CLXX")
public class GxWwSqxxClxx implements Serializable {
    private static final long serialVersionUID = 7007384048258765364L;
    @Id
    private String clid;
    private String clmc;//材料名称
    private String sqxxid;//GX_WW_SQXX id
    private String cllx;//材料类型
    private Integer xh;//序号
    private String xmid;//项目ID
    private Integer fs;//份数
    private Integer ys;//页数


    public String getClid() {
        return clid;
    }

    public void setClid(String clid) {
        this.clid = clid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Integer getFs() {
        return fs;
    }

    public void setFs(Integer fs) {
        this.fs = fs;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }
}
